@@ -19,17 +19,12 @@
 ##
 
 '''
-CAN protocol decoder.
-
-TODO: Description.
-
-Details:
-TODO
-
-Protocol output format:
-
-TODO.
+CAN (Controller Area Network) is a field bus protocol for distributed
+real-time control.
 
+This decoder assumes that a single CAN_RX line is sampled (e.g. on
+the digital output side of a CAN transceiver IC such as the Microchip
+MCP-2515DM-BM).
 '''
 
 from .pd import *
