@@ -19,10 +19,8 @@
 ##
 
 '''
-Dallas DS1307 RTC protocol decoder.
-
-Details:
-TODO
+This decoder stacks on top of the 'i2c' PD and decodes the Dallas DS1307
+real-time clock (RTC) specific registers and commands.
 '''
 
 from .pd import *
