@@ -17,8 +17,6 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 ##
 
-# EDID protocol decoder
-
 # TODO:
 #    - EDID < 1.3
 #    - add short annotations
@@ -70,12 +68,12 @@ xy_ratio = [
     (16, 9),
 ]
 
-# Annotation types
+# Annotation classes
 ANN_FIELDS = 0
 ANN_SECTIONS = 1
 
 class Decoder(srd.Decoder):
-    api_version = 1
+    api_version = 2
     id = 'edid'
     name = 'EDID'
     longname = 'Extended Display Identification Data'
@@ -83,13 +81,10 @@ class Decoder(srd.Decoder):
     license = 'gplv3+'
     inputs = ['i2c']
     outputs = ['edid']
-    probes = []
-    optional_probes = []
-    options = {}
-    annotations = [
-        ['EDID fields', 'EDID structure fields'],
-        ['EDID sections', 'EDID structure sections'],
-    ]
+    annotations = (
+        ('fields', 'EDID structure fields'),
+        ('sections', 'EDID structure sections'),
+    )
 
     def __init__(self, **kwargs):
         self.state = None
@@ -100,11 +95,8 @@ class Decoder(srd.Decoder):
         # Received data
         self.cache = []
 
-    def start(self, metadata):
-        self.out_ann = self.add(srd.OUTPUT_ANN, 'edid')
-
-    def report(self):
-        pass
+    def start(self):
+        self.out_ann = self.register(srd.OUTPUT_ANN)
 
     def decode(self, ss, es, data):
         cmd, data = data
