@@ -19,9 +19,10 @@
 ##
 
 '''
-I2S protocol decoder.
+I²S (Integrated Interchip Sound) is a serial bus for connecting digital
+audio devices (usually on the same device/board).
 
-Documentation:
+Details:
 http://www.nxp.com/acrobat_download/various/I2SBUS.pdf
 http://en.wikipedia.org/wiki/I2s
 '''
