@@ -19,10 +19,8 @@
 ##
 
 '''
-Low-Pin Count protocol decoder.
-
-Details:
-TODO
+LPC (Low-Pin Count) is a protocol for low-bandwidth devices used on
+some PC mainboards, such as the "BIOS chip" or the so-called "Super I/O".
 '''
 
 from .pd import *
