@@ -19,11 +19,10 @@
 ##
 
 '''
-Macronix MX25Lxx05D SPI (NOR) flash chip protocol decoder.
+This decoder stacks on top of the 'spi' PD and decodes the Macronix
+MX25Lxx05D SPI (NOR) flash chip protocol.
 
-Works for MX25L1605D/MX25L3205D/MX25L6405D.
-
-TODO: Description.
+It works for the MX25L1605D/MX25L3205D/MX25L6405D.
 
 Details:
 http://www.macronix.com/QuickPlace/hq/PageLibrary4825740B00298A3B.nsf/h_Index/3F21BAC2E121E17848257639003A3146/$File/MX25L1605D-3205D-6405D-1.5.pdf
