@@ -19,15 +19,11 @@
 ##
 
 '''
-MEMSIC MXC6225XU protocol decoder.
+This decoder stacks on top of the 'i2c' PD and decodes the MEMSIC MXC6225XU
+digital thermal orientation sensor (DTOS) protocol.
 
-The MEMSIC MXC6225XU is a Digital Thermal Orientation Sensor (DTOS).
-
-The chip's I2C interface supports standard mode and fast mode (max. 400kHz).
-Its I2C slave address is 0x2a.
-
-Details:
-TODO
+The chip's I²C interface supports standard mode and fast mode (max. 400kHz).
+Its I²C slave address is 0x2a.
 '''
 
 from .pd import *
