@@ -19,10 +19,8 @@
 ##
 
 '''
-Epson RTC-8564 JE/NB protocol decoder.
-
-Details:
-TODO
+This decoder stacks on top of the 'i2c' PD and decodes the Epson
+RTC-8564 JE/NB real-time clock (RTC) protocol.
 '''
 
 from .pd import *
