@@ -19,12 +19,7 @@
 ##
 
 '''
-Texas Instruments TLC5620 protocol decoder.
-
-TODO: Description.
-
-Details:
-TODO
+The Texas Instruments TLC5620 is an 8-bit quad DAC.
 '''
 
 from .pd import *
